==> UPS-courier_v1.4.2.zip: UPS-courier v1.4.2/UPS-courier v1.4.2.oxp/Scripts/upsMidair.js <==
this.name      = "upsMidair"; 
this.author    = "eric walch"; 
this.copyright = " 2008 the Oolite team."; 
this.version   = "1.01";

this.shipSpawned = function()
{
    this.ship.switchAI("midairUpsJSAI.plist");
    this.collissionradius = 100
    this.shipName = this.ship.shipDisplayName
    this.countdown = 5
    delete this.shipSpawned;
}

this.checkDistance = function()
{
  let distance = Math.round(player.position.distanceTo(this.ship))
  if (distance < 6000)
  {
  player.consoleMessage("You are on approach, lower your speed", 9)
  this.ship.shipDisplayName = this.shipName + " with packages"
  this.ship.reactToAIMessage("UPS_PLAYER_APPROACHING")
  }
}

this.guideIn = function()
{
    let distance = Math.round(player.position.distanceTo(this.ship)) - this.collissionradius
    let speed = Math.round(player.speed)
    if (distance > 7000)
    {
        this.ship.reactToAIMessage("UPS_PLAYER_LEAVING"); return
    }
    if (distance > 1500)
    {
        if(speed > 100) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed.", 5)
    }
    else
    {
        if(speed > 50) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed to 50 km/h.", 4)
        player.consoleMessage("You are at " + distance + " meters, come to a complete standstill within 100 meters.", 4)
    }
    if(distance < 100 && player.speed == 0)
    {
        this.ship.reactToAIMessage("UPS_PLAYER_CLOSE");
    }
}

this.checkSpeed = function()
{
  if (player.speed > 5)
  {
    player.consoleMessage("You are moving to much, lower your speed", 4)
    this.ship.reactToAIMessage("UPS_PLAYER_APPROACHING");
    this.countdown = 5
  }
  else
  {
    player.consoleMessage("Transfering parcels..... " +this.countdown, 3)
    this.countdown--
    if(this.countdown<0)
    {
        this.ship.reactToAIMessage("UPS_TRANSFERING")
    }
  }
}

this.transfer_package = function()
{
    player.consoleMessage("Make room or you will be sucked in my wormhole... ", 8)
    this.ship.shipDisplayName = this.shipName + " without packages"
    missionVariables.ups_pplanetname = expandDescription("[%H]") 
    missionVariables.ups_pplanet = system.ID
    missionVariables.ups_parcel_appearance = expandDescription("[ups_numbers]") + " " + expandDescription("[ups_colors]") + " " + expandDescription("[%I]")
    mission.setInstructionsKey("ups_parcel_midair", "ups_parcel")
    mission.markSystem(system.ID)
    missionVariables.ups_parcel = "MIDAIR_DELIVERY"
  
}

==> UPS-courier_v1.4.3.zip: UPS-courier v1.4.3/UPS-courier v1.4.3.oxp/Scripts/upsMidair.js <==
this.name      = "upsMidair"; 
this.author    = "eric walch"; 
this.copyright = " 2008 eric walch."; 
this.version   = "1.01";

this.shipSpawned = function()
{
    this.ship.switchAI("midairUpsJSAI.plist");
    this.collissionradius = 100
    this.shipName = this.ship.shipDisplayName
    this.countdown = 5
    delete this.shipSpawned;
}

this.checkDistance = function()
{
  let distance = Math.round(worldScripts["ups_container"].playerShip.position.distanceTo(this.ship))
  if (distance < 6000)
  {
  player.consoleMessage("You are on approach, lower your speed", 9)
  this.ship.shipDisplayName = this.shipName + " with packages"
  this.ship.reactToAIMessage("UPS_PLAYER_APPROACHING")
  }
}

this.guideIn = function()
{
    let distance = Math.round(worldScripts["ups_container"].playerShip.position.distanceTo(this.ship)) - this.collissionradius
    let speed = Math.round(worldScripts["ups_container"].playerShip.speed)
    if (distance > 7000)
    {
        this.ship.reactToAIMessage("UPS_PLAYER_LEAVING"); return
    }
    if (distance > 1500)
    {
        if(speed > 100) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed.", 5)
    }
    else
    {
        if(speed > 50) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed to 50 km/h.", 4)
        player.consoleMessage("You are at " + distance + " meters, come to a complete standstill within 100 meters.", 4)
    }
    if(distance < 100 && worldScripts["ups_container"].playerShip.speed == 0)
    {
        this.ship.reactToAIMessage("UPS_PLAYER_CLOSE");
    }
}

this.checkSpeed = function()
{
  if (worldScripts["ups_container"].playerShip.speed > 5)
  {
    player.consoleMessage("You are moving to much, lower your speed", 4)
    this.ship.reactToAIMessage("UPS_PLAYER_APPROACHING");
    this.countdown = 5
  }
  else
  {
    player.consoleMessage("Transfering parcels..... " +this.countdown, 3)
    this.countdown--
    if(this.countdown<0)
    {
        this.ship.reactToAIMessage("UPS_TRANSFERING")
    }
  }
}

this.transfer_package = function()
{
    player.consoleMessage("Make room or you will be sucked in my wormhole... ", 8)
    this.ship.shipDisplayName = this.shipName + " without packages"
    missionVariables.ups_pplanetname = expandDescription("[%H]") 
    missionVariables.ups_pplanet = system.ID
    missionVariables.ups_parcel_appearance = expandDescription("[ups_numbers]") + " " + expandDescription("[ups_colors]") + " " + expandDescription("[%I]")
    mission.setInstructionsKey("ups_parcel_midair", "ups_parcel")
    mission.markSystem(system.ID)
    missionVariables.ups_parcel = "MIDAIR_DELIVERY"
  
}
